pub struct DataLocaleFamily { /* private fields */ }Expand description
A family of locales to export.
Implementations
Sourceimpl DataLocaleFamily
impl DataLocaleFamily
Sourcepub fn with_descendants(locale: DataLocale) -> Self
pub fn with_descendants(locale: DataLocale) -> Self
The family containing all ancestors and descendants of the selected locale.
This is the recommended family type since it reflects regional preferences.
For example, the family ::with_descendants("en-001") contains:
- Self: “en-001”
- Ancestors: “und”, “en”
- Descendants: “en-GB”, “en-ZA”, …
Stylized on the CLI as: “en-US”
The und locale is treated specially and behaves like ::single("und").
Sourcepub fn without_descendants(locale: DataLocale) -> Self
pub fn without_descendants(locale: DataLocale) -> Self
The family containing all ancestors of the selected locale.
This family type does not include regional variants unless the selected locale is itself a regional variant.
For example, the family ::without_descendants("en-001") contains:
- Self: “en-001”
- Ancestors: “und”, “en”
Stylized on the CLI as: “^en-US”
The und locale is treated specially and behaves like ::single("und").
Sourcepub fn without_ancestors(locale: DataLocale) -> Self
pub fn without_ancestors(locale: DataLocale) -> Self
The family containing all descendants of the selected locale.
This family may be useful if the root locale is not desired.
For example, the family ::without_ancestors("en-001") contains:
- Self: “en-001”
- Descendants: “en-GB”, “en-ZA”, …
but it does not contain the ancestors “en” and “und”.
Stylized on the CLI as: “%en-US”
The und locale is treated specially and behaves like ::single("und").
Sourcepub const fn single(locale: DataLocale) -> Self
pub const fn single(locale: DataLocale) -> Self
The family containing only the selected locale.
For example, the family ::single("en-001") contains only “en-001”.
Stylized on the CLI as: “@en-US”
Sourceimpl DataLocaleFamily
impl DataLocaleFamily
Sourcepub fn try_from_utf8(
code_units: &[u8],
) -> Result<Self, DataLocaleFamilyParseError>
pub fn try_from_utf8( code_units: &[u8], ) -> Result<Self, DataLocaleFamilyParseError>
Parses a DataLocaleFamily from a UTF-8 slice.
Sourcepub fn try_from_str(s: &str) -> Result<Self, DataLocaleFamilyParseError>
pub fn try_from_str(s: &str) -> Result<Self, DataLocaleFamilyParseError>
Parses a DataLocaleFamily.